@@ -6,7 +6,7 @@ require Exporter;
 use warnings;
 use strict;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use Carp;
 use Convert::Moji qw/make_regex length_one unambiguous/;
@@ -51,6 +51,7 @@ our @EXPORT_OK = qw/
                     kanji2circled
                     bracketed2kanji
                     kanji2bracketed
+                    katakana2syllable
                     /;
 
 our %EXPORT_TAGS = (
@@ -1080,5 +1081,19 @@ END
     # "other, not assigned".
 }
 
+# お
+
+my $kana2syllable_re = qr/ッ?[アイウエオ-モヤユヨ-ヴ](?:[ャュョァィゥェォ])?ー?/;
+
+sub katakana2syllable
+{
+    my ($kana) = @_;
+    my @pieces;
+    while ($kana =~ /($kana2syllable_re)/g) {
+        push @pieces, $1;
+    }
+    return \@pieces;
+}
+
 1; 
 
